# -*- coding: iso-8859-1 -*-
"""
    sendfiles - Send files using MoinMessage

    @copyright: 2013, 2014 by Paul Boddie <paul@boddie.org.uk>
    @license: GNU GPL (v2 or later), see COPYING.txt for details.
"""

from MoinMessage import Message, GPG, sendMessage, timestamp
from email.mime.application import MIMEApplication
from os.path import split
import sys

def readfile(filename):
    f = open(filename, "rb")
    try:
        return MIMEApplication(f.read())
    finally:
        f.close()

if __name__ == "__main__":
    try:
        recipient = sys.argv[1]
        signer = sys.argv[2]
        url = sys.argv[3]
        args = sys.argv[4:]
    except IndexError:
        args = None

    if not args:
        print >>sys.stderr, """\
Need a recipient key identifier, signing key identifier, the destination URL,
and some filenames for transfer as arguments to this program.
"""
        sys.exit(1)

    # Bundle files into a message.

    message = Message()

    for arg in args:
        part = readfile(arg)
        part["Content-Disposition"] = split(arg)[-1]
        part["Update-Action"] = "store"
        message.add_update(part)

    # Get the e-mail message itself.

    email_message = message.get_payload()

    # Sign, encrypt, sign and send the message.

    gpg = GPG()
    signed_message = gpg.signMessage(email_message, signer)
    encrypted_message = gpg.encryptMessage(signed_message, recipient)

    timestamp(encrypted_message)
    encrypted_message["Update-Action"] = "store"
    message_to_send = gpg.signMessage(encrypted_message, signer)

    resp = sendMessage(message_to_send, url)

    print resp

# vim: tabstop=4 expandtab shiftwidth=4
